#!/bin/bash

NAME=$(basename $PWD)
OWNER=$(sed   -n '/^%global gh_owner/{s/.* //;p}'   $NAME.spec)
PROJECT=$(sed -n '/^%global gh_project/{s/.* //;p}' $NAME.spec)
COMMIT=$(sed -n '/^%global gh_commit/{s/.* //;p}'   $NAME.spec)
TAG=$(sed -n '/^%global gh_tag/{s/.* //;p}'         $NAME.spec)
VERSION=$(sed -n '/^Version:/{s/.* //;p}'           $NAME.spec)

if [ -f $NAME-$VERSION.tgz ]; then
	echo Skip $NAME-$VERSION.tgz
else
	echo -e "\nCreate git snapshot\nName=$NAME, Owner=$OWNER, Project=$PROJECT, Version=$VERSION\n"

	echo "Cloning..."
	rm -rf $PROJECT-$VERSION

	if [ -z "$TAG" ]; then
		git clone --recursive https://github.com/$OWNER/$PROJECT.git $PROJECT-$VERSION
		pushd $PROJECT-$VERSION
			git checkout $COMMIT || exit 1
		popd
	else
		git clone --recursive --branch $TAG https://github.com/$OWNER/$PROJECT.git $PROJECT-$VERSION
	fi

	echo "Archiving..."
	tar czf $NAME-$VERSION.tgz --exclude .git $PROJECT-$VERSION

	echo "Cleaning..."
	rm -rf $PROJECT-$VERSION

	echo "Done."
fi

spectool -g -S *spec

